@@ -14,11 +14,15 @@ import tokenize
 # Third-Party Libraries
 import numpy
 
+#
+# Metadata
+# ------------------------------------------------------------------------------
+#
+from about_numtest import *
 
-__author__  = u"Sébastien Boisgérault <Sebastien.Boisgerault@mines-paristech.fr>"
-__version__ = "1.1.1"
-__license__ = "MIT License"
-__url__     = "https://github.com/boisgera/numtest"
+#
+# ------------------------------------------------------------------------------
+#
 
 _doctest_OutputChecker = doctest.OutputChecker
 
@@ -210,6 +214,8 @@ Test the directive on arrays:
     [1]
     >>> array([-1.0]) # doctest: +NUMBER
     [-1.0]
+    >>> array([-1.0, 1.0, -1.0, 1.0]) # doctest: +NUMBER
+    [-1.0, 1.0, -1.0, 1.0]
     >>> array([[1.0, 2.0], [3.0, 4.0]]) # doctest: +NUMBER
     [[1, 2], [3, 4]]
     """
